Blockchain backends
This module provides the implementation of a few commonly-used backends like
Electrum, Esplora and
Compact Filters/Neutrino, along with a generalized trait
Blockchain that can be implemented to build customized backends.
Re-exports
pub use any::AnyBlockchain;pub use any::AnyBlockchainConfig;pub use self::electrum::ElectrumBlockchain;pub use self::electrum::ElectrumBlockchainConfig;pub use self::rpc::RpcBlockchain;pub use self::rpc::RpcConfig;pub use self::esplora::EsploraBlockchain;pub use self::compact_filters::CompactFiltersBlockchain;
Modules
- any
- Runtime-checked blockchain types
- compact_
filters compact_filters - Compact Filters
- electrum
electrum - Electrum
- esplora
esplora - Esplora
- rpc
rpc - Rpc Blockchain
Structs
- LogProgress
- Type that implements
Progressand logs at levelINFOevery update received - Noop
Progress - Type that implements
Progressand drops every update received
Enums
- Capability
- Capabilities that can be supported by a
Blockchainbackend
Traits
- Blockchain
- Trait that defines the actions that must be supported by a blockchain backend
- Blockchain
Factory - Trait for a factory of blockchains that share the underlying connection or configuration
- Configurable
Blockchain - Trait for
Blockchaintypes that can be created given a configuration - GetBlock
Hash - Trait for getting block hash by block height
- GetHeight
- Trait for getting the current height of the blockchain.
- GetTx
- Trait for getting a transaction by txid
- Progress
- Trait for types that can receive and process progress updates during
WalletSync::wallet_syncandWalletSync::wallet_setup - Stateless
Blockchain - Trait for blockchains that don’t contain any state
- Wallet
Sync - Trait for blockchains that can sync by updating the database directly.
Functions
- log_
progress - Create a new instance of
LogProgress - noop_
progress - Create a new instance of
NoopProgress - progress
- Shortcut to create a
channel(pair ofSenderandReceiver) that can transportProgressData
Type Aliases
- Progress
Data - Data sent with a progress update over a
channel